<!DOCTYPE html>
<html>
  <head>
    <title>{{title}}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <link type="text/css" rel="stylesheet" href="{{asset 'css/style.css'}}" />
    <link type="text/css" rel="stylesheet" href="{{asset 'css/pilcrow.css'}}" />
    <link type="text/css" rel="stylesheet" href="{{asset 'css/hljs-github.min.css'}}"/>
  </head>
<body>
<div class="content">
{{~> content}}
</div>
</body>
</html>
